
# Type: regulates




URI: [biolink:regulates](https://w3id.org/biolink/vocab/regulates)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>0..*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [affects](affects.md)

## Children

 *  [negatively regulates](negatively_regulates.md)
 *  [positively regulates](positively_regulates.md)
 *  [regulates, entity to entity](regulates_entity_to_entity.md)
 *  [regulates, process to process](regulates_process_to_process.md)

## Used by

 * [NamedThing](NamedThing.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | WD:P128 |
| **Comments:** | | This is a grouping for process-process and entity-entity relations |

